@@ -49,4 +49,4 @@ return J.api.JmolAdapter.canonizeAlphaDigit(altLoc);
 }, "~S");
 c$.cellParamNames =  Clazz.newArray(-1, ["_cell_length_a", "_cell_length_b", "_cell_length_c", "_cell_angle_alpha", "_cell_angle_beta", "_cell_angle_gamma"]);
 });
-;//5.0.1-v7 Wed Dec 31 15:00:35 CST 2025
+;//5.0.1-v7 Sat Feb 21 18:17:38 CST 2026
